.. Mistral documentation master file, created by
   sphinx-quickstart on Fri Nov  1 02:06:28 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mistral's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   develop_applications/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

